# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2020-04-16 14:38:22
@LastEditTime: 2022-03-08 17:34:29
@LastEditors: HuangJianYi
:Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
"""
# 框架引用
from seven_framework.web_tornado.monitor import MonitorHandler
from seven_cloudapp_frame.handlers.core import *
from seven_cloudapp_frame.handlers.server import *
from seven_cloudapp_frame.handlers.client import *


def seven_cloudapp_frame_route():
    return [
        (r"/monitor", MonitorHandler),
        (r"/", IndexHandler),
        #客户端
        (r"/client/address_list", address.AddressInfoListHandler),  #收货地址列表
        (r"/client/login", user.LoginHandler),  #小程序登录
        (r"/client/update_user_info", user.UpdateUserInfoHandler),  #更新用户信息如昵称、头像等
        (r"/client/check_is_member", user.CheckIsMemberHandler),  #校验是否是店铺会员
        (r"/client/apply_black_unbind", user.ApplyBlackUnbindHandler),  #申请黑名单解封
        (r"/client/get_unbind_apply", user.GetUnbindApplyHandler),  #获取黑名单解封申请记录
        (r"/client/user_asset_list", user.GetUserAssetHandler),  #获取单条用户资产
        (r"/client/user_asset_list", user.UserAssetListHandler),  #用户资产列表
        (r"/client/asset_log_list", user.AssetLogListHandler),  #用户资产流水列表
        (r"/client/get_join_member_url", user.GetJoinMemberUrlHandler),  #加入会员地址
        (r"/client/get_coupon_prize", user.GetCouponPrizeHandler),  #领取淘宝优惠券
        (r"/client/user_address_list", user.UserAddressListHandler),  #收货地址列表
        (r"/client/save_user_address", user.SaveUserAddressHandler),  #保存收货地址
        (r"/client/get_crm_integral", user.GetCrmIntegralHandler),  #获取淘宝店铺积分
        (r"/client/theme_info", theme.ThemeInfoHandler),  #主题信息
        (r"/client/save_theme", theme.SaveThemeHandler),  #保存主题信息，由前端通过工具进行保存
        (r"/client/save_skin", theme.SaveSkinHandler),  #保存皮肤信息，由前端通过工具进行保存
        (r"/client/theme_info_list", theme.ThemeInfoListHandler),  #主题列表
        (r"/client/skin_info_list", theme.SkinInfoListHandler),  #皮肤列表
        (r"/client/ip_info_list", ip.IpInfoListHandler),  #ip信息列表
        (r"/client/act_info", act.ActInfoHandler),  #活动信息
        (r"/client/act_prize_list", act.ActPrizeListHandler),  #活动奖品列表
        (r"/client/cms_info_list", act.CmsInfoListHandler),  #位置信息列表
        (r"/client/price_gear_list", act.PriceGearListHandler),  #价格档位列表
        (r"/client/app_expire", app.AppExpireHandler),  #小程序过期时间
        (r"/client/get_high_power_list", app.GetHighPowerListHandler),  #获取中台配置的高级权限列表
        (r"/client/add_wechat_subscribe", app.AddWechatSubscribeHandler),  #添加微信订阅次数
        (r"/client/sku_info", goods.SkuInfoHandler),  #sku信息
        (r"/client/goods_list", goods.GoodsListHandler),  #商品列表
        (r"/client/horseracelamp_list", order.HorseracelampListHandler),  #中奖记录跑马灯列表
        (r"/client/prize_order_list", order.PrizeOrderListHandler),  #用户订单列表
        (r"/client/create_prize_order", order.SelectPrizeOrderHandler),  #选择中奖记录进行下单
        (r"/client/submit_sku", order.SubmitSkuHandler),  #中奖记录选择sku
        (r"/client/prize_roster_list", order.PrizeRosterListHandler),  #中奖记录列表
        (r"/client/sync_pay_order", order.SyncPayOrderHandler),  #同步淘宝支付订单给用户加资产
        (r"/client/task_info_list", task.TaskInfoListHandler),  #任务列表
        (r"/client/receive_reward", task.ReceiveRewardHandler),  #统一领取任务奖励
        (r"/client/free_gift", task.FreeGiftHandler),  #免费领取、新人有礼等任务
        (r"/client/one_sign", task.OneSignHandler),  #单次签到任务
        (r"/client/weekly_sign", task.WeeklySignHandler),  #每周签到任务
        (r"/client/cumulative_sign", task.CumulativeSignHandler),  #累计签到任务
        (r"/client/invite_new_user", task.InviteNewUserHandler),  #邀请新用户任务
        (r"/client/invite_join_member", task.InviteJoinMemberHandler),  #邀请加入会员任务
        (r"/client/browse_site", task.BrowseSiteHandler),  #处理浏览网址相关任务 如：浏览店铺、浏览直播间、浏览会场/专题
        (r"/client/collect_goods", task.CollectGoodsHandler),  #收藏商品任务
        (r"/client/browse_goods", task.BrowseGoodsHandler),  #浏览商品任务
        (r"/client/favor_store", task.FavorStoreHandler),  #关注店铺任务
        (r"/client/join_member", task.JoinMemberHandler),  #加入会员任务
        (r"/client/task_share", task.ShareHandler),  #分享奖励任务
        (r"/client/share_report", stat.ShareReportHandler),  #分享统计上报
        (r"/client/invite_report", stat.InviteReportHandler),  #邀请进入统计上报
        (r"/client/wvoucher_order", pay.WechatVoucherOrderHandler),  #创建微信预订单
        (r"/client/wpay_notify", pay.WechatPayNotifyHandler),  #微信支付异步通知
        (r"/client/wrefund_notify", pay.WechatRefundNotifyHandler),  #微信退款异步通知
        (r"/client/tvoucher_order", pay.TiktokVoucherOrderHandler),  #创建抖音预订单
        (r"/client/tpay_notify", pay.TiktokPayNotifyHandler),  #抖音支付异步通知
        (r"/client/trefund_notify", pay.TiktokRefundNotifyHandler),  #抖音退款异步通知

        #后台和千牛端
        (r"/server/left_navigation", base_s.LeftNavigationHandler),  #左侧导航
        (r"/server/friend_link_list", base_s.FriendLinkListHandler),  #获取友情链接产品互推列表
        (r"/server/send_sms", base_s.SendSmsHandler),  #发短信
        (r"/server/cms_info_list", base_s.CmsInfoListHandler),  #位置信息列表
        (r"/server/save_cms_info", base_s.SaveCmsInfoHandler),  #保存位置信息
        (r"/server/get_product_price", base_s.GetProductPriceHandler),  #获取产品价格信息
        (r"/server/get_high_power_list", app_s.GetHighPowerListHandler),  #获取中台配置的高级权限列表
        (r"/server/app_info", app_s.AppInfoHandler),  #应用信息
        (r"/server/check_gm_power", app_s.CheckGmPowerHandler),  #根据店铺名称返回应用标识 用于GM工具
        (r"/server/get_appid_by_gm", app_s.GetAppidByGmHandler),  #获取是否有GM工具权限 用于GM工具
        (r"/server/instantiate", app_s.InstantiateAppHandler),  #实例化小程序
        (r"/server/version_upgrade", app_s.VersionUpgradeHandler),  #小程序端版本升级
        (r"/server/update_telephone", app_s.UpdateTelephoneHandler),  #更新手机号
        (r"/server/get_short_url", app_s.GetShortUrlHandler),  #淘宝短链接
        (r"/server/act_type_list", act_s.ActTypeListHandler),  #活动类型列表
        (r"/server/next_progress", act_s.NextProgressHandler),  #活动下一步操作
        (r"/server/add_act_info", act_s.AddActInfoHandler),  #添加活动
        (r"/server/update_act_info", act_s.UpdateActInfoHandler),  #修改活动
        (r"/server/act_info_list", act_s.ActInfoListHandler),  #活动列表
        (r"/server/act_info", act_s.ActInfoHandler),  #单条活动信息
        (r"/server/delete_act_info", act_s.DeleteActInfoHandler),  #删除活动（假删除）
        (r"/server/review_act_info", act_s.ReviewActInfoHandler),  #还原活动
        (r"/server/release_act_info", act_s.ReleaseActInfoHandler),  #上下架活动
        (r"/server/create_act_qrcode", act_s.CreateActQrCodeHandler),  #生成小程序二维码
        (r"/server/save_act_module", module_s.SaveActModuleHandler),  #保存活动模块信息（保存新增和修改）
        (r"/server/act_module", module_s.ActModuleHandler),  #单条活动模块信息
        (r"/server/act_module_list", module_s.ActModuleListHandler),  #活动模块列表
        (r"/server/delete_act_module", module_s.DeleteActModuleHandler),  #删除活动模块（假删除）
        (r"/server/review_act_module", module_s.ReviewActModuleHandler),  #还原活动模块
        (r"/server/release_act_module", module_s.ReleaseActModuleHandler),  #上下架活动模块
        (r"/server/save_act_prize", prize_s.SaveActPrizeHandler),  #保存活动奖品
        (r"/server/act_prize_list", prize_s.ActPrizeListHandler),  #活动奖品列表
        (r"/server/delete_act_prize", prize_s.DeleteActPrizeHandler),  #删除活动奖品（假删除）
        (r"/server/review_act_prize", prize_s.ReviewActPrizeHandler),  #还原活动奖品
        (r"/server/release_act_prize", prize_s.ReleaseActPrizeHandler),  #上下架活动奖品
        (r"/server/act_prize_export", prize_s.ActPrizeExportHandler),  #导出活动奖品列表
        (r"/server/pay_order_list", order_s.PayOrderListHandler),  #淘宝支付订单列表
        (r"/server/prize_order_list", order_s.PrizeOrderListHandler),  #奖品订单列表
        (r"/server/prize_roster_list", order_s.PrizeRosterListHandler),  #用户中奖记录列表
        (r"/server/prize_order_export", order_s.PrizeOrderExportHandler),  #导出奖品订单列表
        (r"/server/prize_roster_export", order_s.PrizeRosterExportHandler),  #导出用户中奖记录列表
        (r"/server/tao_pay_order_export", order_s.TaoPayOrderExportHandler),  #导出淘宝订单列表
        (r"/server/update_prize_order_status", order_s.UpdatePrizeOrderStatusHandler),  #更新奖品订单状态
        (r"/server/update_prize_order_seller_remark", order_s.UpdatePrizeOrderSellerRemarkHandler),  #更新奖品订单卖家备注
        (r"/server/import_prize_order", order_s.ImportPrizeOrderHandler),  #导入发货订单
        (r"/server/stat_report_list", report_s.StatReportListHandler),  #报表数据列表(表格)
        (r"/server/trend_report_list", report_s.TrendReportListHandler),  #报表数据列表(趋势图)
        (r"/server/login", user_s.LoginHandler),  #千牛端登录
        (r"/server/user_info_list", user_s.UserInfoListHandler),  #用户信息列表
        (r"/server/update_user_status", user_s.UpdateUserStatusHandler),  #更新用户状态（0正常1黑名单）
        (r"/server/update_user_status_by_black", user_s.UpdateUserStatusByBlackHandler),  #更新用户状态(黑名单管理模式)
        (r"/server/audit_user_black", user_s.AuditUserBlackHandler),  #审核黑名单状态
        (r"/server/update_audit_remark", user_s.UpdateAuditRemarkHandler),  #修改审核备注
        (r"/server/user_black_list", user_s.UserBlackListHandler),  #黑名单列表
        (r"/server/update_user_asset", user_s.UpdateUserAssetHandler),  #更新用户资产值
        (r"/server/batch_update_user_asset", user_s.BatchUpdateUserAssetHandler),  #批量更新用户资产值
        (r"/server/user_asset_list", user_s.UserAssetListHandler),  #用户资产列表
        (r"/server/asset_log_list", user_s.AssetLogListHandler),  #资产流水列表
        (r"/server/init_launch_goods", launch_s.ResetLaunchGoodsHandler),  #重置商品投放 删除已投放的记录并将活动投放状态改为未投放
        (r"/server/init_launch_goods", launch_s.InitLaunchGoodsHandler),  #初始化投放商品
        (r"/server/async_launch_goods", launch_s.AsyncLaunchGoodsHandler),  #同步投放商品（小程序投放-商品绑定/解绑）
        (r"/server/launch_goods_list", launch_s.LaunchGoodsListHandler),  #投放商品列表
        (r"/server/update_launch_goods_status", launch_s.UpdateLaunchGoodsStatusHandler),  #更新投放商品的状态
        (r"/server/init_launch_goods_callback", launch_s.InitLaunchGoodsCallBackHandler),  #初始化投放商品回调接口
        (r"/server/update_theme", theme_s.UpdateThemeHandler),  #更新主题
        (r"/server/theme_info_list", theme_s.ThemeInfoListHandler),  #主题信息列表
        (r"/server/skin_info_list", theme_s.SkinInfoListHandler),  #皮肤信息列表
        (r"/server/save_ip_info", ip_s.SaveIpInfoHandler),  #保存ip信息
        (r"/server/delete_ip_info", ip_s.DeleteIpInfoHandler),  #删除ip信息
        (r"/server/ip_info_list", ip_s.IpInfoListHandler),  #ip信息列表
        (r"/server/release_ip_info", ip_s.ReleaseIpInfoHandler),  #上下架ip信息
        (r"/server/save_price_gear", price_s.SavePriceGearHandler),  #保存价格档位信息
        (r"/server/price_gear_list", price_s.PriceGearListHandler),  #价格档位列表
        (r"/server/delete_price_gear", price_s.DeletePriceGearHandler),  #删除价格档位（假删除）
        (r"/server/review_price_gear", price_s.ReviewPriceGearHandler),  #还原价格档位
        (r"/server/check_price_gear", price_s.CheckPriceGearHandler),  #校验价格档位
        (r"/server/inventory_goods_list", goods_s.InventoryGoodsListHandler),  #仓库中的商品列表
        (r"/server/goods_list", goods_s.GoodsListHandler),  #在售中的商品列表
        (r"/server/goods_list_by_goodsids", goods_s.GoodsListByGoodsIDHandler),  #根据商品ID返回在售中商品列表
        (r"/server/goods_info", goods_s.GoodsInfoHandler),  #商品信息
        (r"/server/benefit_detail", goods_s.BenefitDetailHandler),  #获取优惠券详情信息
        (r"/server/task_info_list", task_s.TaskInfoListHandler),  #任务信息列表
        (r"/server/save_task_info", task_s.SaveTaskInfoHandler),  #保存任务信息
        (r"/server/special_goods_list", goods_s.SpecialGoodsListHandler),  #专属下单商品列表
        (r"/server/bind_special_goods", goods_s.BindSpecialGoodsHandler),  #专属下单商品绑定
    ]


# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2020-08-12 09:06:24
@LastEditTime: 2022-03-09 09:17:57
@LastEditors: HuangJianYi
:description: 淘宝top接口基础类
"""
from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
from seven_top import top
from seven_cloudapp_frame.models.db_models.base.base_info_model import *
from seven_cloudapp_frame.models.db_models.app.app_info_model import *
from seven_cloudapp_frame.models.seven_model import *

class TopBaseModel():
    """
    :description: 淘宝top接口业务模型
    """
    def __init__(self,context=None,logging_error=None,logging_info=None):
        self.context = context
        self.logging_link_error = logging_error
        self.logging_link_info = logging_info

    def instantiate(self,app_id,user_nick,access_token,app_key, app_secret,is_log=False):
        """
        :description: 实例化
        :param app_id:应用标识
        :param user_nick:用户昵称
        :param access_token:access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()

        base_info = BaseInfoModel(context=self.context).get_entity()
        if not base_info:
            invoke_result_data.success = False
            invoke_result_data.error_code = "error"
            invoke_result_data.error_message = "基础信息未配置"
            return invoke_result_data

        app_name = base_info.product_name
        description = base_info.product_desc
        icon = base_info.product_icon
        template_id = config.get_value("client_template_id")
        template_version = base_info.client_ver
        app_info_model = AppInfoModel(context=self.context)
        app_info = None

        # 产品千牛后台GM工具（运营人员模拟登录）
        if app_id:
            app_info = app_info_model.get_cache_entity(where="app_id=%s", params=app_id)
            if app_info:
                invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": app_info.store_user_nick, "access_token": app_info.access_token}
                return invoke_result_data
            invoke_result_data.success = False
            invoke_result_data.error_code = "error"
            invoke_result_data.error_message = "对不起，该店铺未实例化。"
            return invoke_result_data

        if not user_nick:
            invoke_result_data.success = False
            invoke_result_data.error_code = "error"
            invoke_result_data.error_message = "对不起,请先授权登录"
            return invoke_result_data
        store_user_nick = user_nick.split(':')[0]
        if not store_user_nick:
            invoke_result_data.success = False
            invoke_result_data.error_code = "error"
            invoke_result_data.error_message = "对不起,请先授权登录"
            return invoke_result_data
        app_info = app_info_model.get_cache_entity(where="store_user_nick=%s", params=store_user_nick)
        # 有效时间获取
        invoke_result_data = self.get_dead_date(store_user_nick, access_token, app_key, app_secret, is_log)
        if invoke_result_data.success == False:
            return invoke_result_data
        dead_date = invoke_result_data.data
        project_code = self.get_project_code(store_user_nick,access_token, app_key, app_secret, is_log)
        if app_info:
            if dead_date != "expire":
                app_info.expiration_date = dead_date
            if project_code != "":
                app_info.project_code = project_code
            invoke_result_data = self.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
            if invoke_result_data.success == True:
                app_info.access_token = access_token
            app_info_model.update_entity(app_info, "expiration_date,project_code,access_token")
            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": user_nick, "access_token": app_info.access_token}
            return invoke_result_data

        # if ":" in user_nick:
        #     invoke_result_data.success = False
        #     invoke_result_data.error_code = "account_error"
        #     invoke_result_data.error_message = "对不起，初次创建活动包含实例化，请使用主账号进行创建。"
        #     return invoke_result_data

        invoke_result_data = self.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
        if invoke_result_data.success == False:
            invoke_result_data.error_code = "account_error"
            invoke_result_data.error_message = "对不起，请使用主账号或者授权的子账号进行创建"
            return invoke_result_data
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.MiniappTemplateInstantiateRequest()
            req.clients = "taobao,tmall"
            req.description = description

            invoke_result_data = self.get_shop(access_token,app_key,app_secret, is_log)
            shop_info = invoke_result_data.data if invoke_result_data.success == True else {}

            req.ext_json = "{ \"name\":\"" + app_name + "\"}"
            req.icon = icon
            req.alias = app_name
            req.template_id = template_id
            req.template_version = template_version
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【小程序实例化】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)

            #录入数据库
            result_app = resp["miniapp_template_instantiate_response"]
            app_info = AppInfo()
            app_info.clients = req.clients
            app_info.app_desc = result_app["app_description"]
            app_info.app_icon = result_app["app_icon"]
            app_info.app_id = result_app["app_id"]
            app_info.app_name = result_app["app_name"]
            app_info.app_ver = result_app["app_version"]
            app_info.app_key = result_app["appkey"]
            app_info.preview_url = result_app["pre_view_url"]
            app_info.template_id = req.template_id
            app_info.template_ver = req.template_version
            app_info.access_token = access_token
            app_info.expiration_date = dead_date
            app_info.project_code = project_code

            if "shop_seller_get_response" in shop_info.keys():
                app_info.store_name = shop_info["shop_seller_get_response"]["shop"]["title"]
                app_info.store_id = shop_info["shop_seller_get_response"]["shop"]["sid"]
                app_info.store_icon = shop_info["shop_seller_get_response"]["shop"]["pic_path"]
                if app_info.store_icon != "":
                    app_info.store_icon = "http://logo.taobao.com/shop-logo" + app_info.store_icon

            invoke_result_data = self.get_user_seller(access_token,app_key,app_secret, is_log)
            user_seller = invoke_result_data.data if invoke_result_data.success == True else {}
            if "user_seller_get_response" in user_seller.keys():
                app_info.seller_id = user_seller["user_seller_get_response"]["user"]["user_id"]

            app_info.is_instance = 1
            app_info.store_user_nick = store_user_nick
            app_info.instance_date = SevenHelper.get_now_datetime()
            app_info.modify_date = SevenHelper.get_now_datetime()
            #上线
            invoke_result_data = self.online_app(app_info.app_id, template_id, template_version, app_info.app_ver, access_token, app_key, app_secret, is_log)
            if invoke_result_data.success == False:
                return invoke_result_data
            online_app_info = invoke_result_data.data
            if "miniapp_template_onlineapp_response" in online_app_info.keys():
                app_info.app_url = online_app_info["miniapp_template_onlineapp_response"]["app_info"]["online_url"]
            app_info.id = app_info_model.add_entity(app_info)
            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": store_user_nick, "user_nick": user_nick, "access_token": access_token}
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=" in content:
                        invoke_result_data.success = False
                        invoke_result_data.error_code = "create_error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        invoke_result_data.data = {"icon": icon, "app_name": app_name}
                        return invoke_result_data

    def version_upgrade(self, app_id, client_template_id, client_ver, access_token,app_key, app_secret, app_info, is_log=False):
        """
        :description: app更新 接口权限包：商家应用-模板实例化权限包
        :param app_id:app_id
        :param client_template_id:模板id
        :param client_ver:更新的版本号
        :param access_token:access_token
        :param app_info:app_info
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.MiniappTemplateUpdateappRequest()

            req.clients = "taobao,tmall"
            req.app_id = app_id
            req.template_id = client_template_id
            req.template_version = client_ver
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【app更新】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if resp and ("miniapp_template_updateapp_response" in resp.keys()):
                app_version = resp["miniapp_template_updateapp_response"]["app_version"]
                invoke_result_data = self.online_app(app_id, client_template_id, client_ver, app_version, access_token, app_key, app_secret, is_log)
                online_app_info = invoke_result_data.data if invoke_result_data.success == True else {}
                if "miniapp_template_onlineapp_response" in online_app_info.keys():
                    app_info.app_ver = resp["miniapp_template_updateapp_response"]["app_version"]
                    app_info.template_ver = client_ver
                    app_info.modify_date = SevenHelper.get_now_datetime()
                    AppInfoModel(context=self.context).update_entity(app_info, "app_ver,template_ver,modify_date")
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_sku_name(self, num_iids, sku_id, access_token,app_key, app_secret,is_log=False):
        """
        :description: 获取sku名称
        :param num_iids：num_iids
        :param sku_id：sku_id
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.ItemsSellerListGetRequest()
            req.fields = "num_iid,title,nick,input_str,property_alias,sku,props_name,pic_url"
            req.num_iids = num_iids
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【获取sku名称】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if "items_seller_list_get_response" in resp.keys():
                if "items" in resp["items_seller_list_get_response"].keys():
                    props_names = resp["items_seller_list_get_response"]["items"]["item"][0]["props_name"].split(';')
                    for sku in resp["items_seller_list_get_response"]["items"]["item"][0]["skus"]["sku"]:
                        if sku["sku_id"] == sku_id:
                            props_name = [i for i in props_names if sku["properties"] in i]
                            if len(props_name) > 0:
                                invoke_result_data.data = props_name[0][(len(sku["properties"]) + 1):]
                            else:
                                invoke_result_data.data = sku["properties_name"].split(':')[1]
                            return invoke_result_data
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_buy_order_info(self, order_no, access_token,app_key, app_secret,is_log=False):
        """
        :description: 获取单笔订单
        :param order_no：订单编号
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return: InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.OpenTradeGetRequest()

            req.fields = "tid,status,payment,price,created,orders,num,pay_time,buyer_open_uid"
            req.tid = order_no
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【获取单笔订单】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if "open_trade_get_response" in resp.keys():
                if "trade" in resp["open_trade_get_response"]:
                    invoke_result_data.data = resp["open_trade_get_response"]["trade"]
                    return invoke_result_data
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_buy_order_list(self, open_id, access_token, app_key, app_secret, start_created="", end_created="", page_size=50, is_log=False, type="fixed,step",field="tid,status,payment,price,created,orders,num,pay_time,step_trade_status,step_paid_fee,type"):
        """
        :description: 获取淘宝购买订单
        :param open_id：open_id
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param start_created：开始时间
        :param end_created：结束时间
        :param page_size：页大小
        :param is_log：是否记录返回信息
        :param type：订单类型
        :param field：返回字段
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        all_order = []
        has_next = True
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.OpenTradesSoldGetRequest()
            req.fields = field
            req.type = type
            req.buyer_open_id = open_id
            req.page_size = page_size
            req.page_no = 1
            req.use_has_next = "true"

            if start_created == "":
                start_timestamp = TimeHelper.get_now_timestamp() - 90 * 24 * 60 * 60
                start_created = TimeHelper.timestamp_to_format_time(start_timestamp)
            req.start_created = start_created
            if end_created != "":
                req.end_created = end_created

            while has_next:
                resp = req.getResponse(access_token)
                if is_log:
                    log_info = str(resp) + "【access_token】：" + access_token + "【获取购买订单】"
                    if self.context:
                        self.context.logging_link_info(log_info)
                    elif self.logging_link_info:
                        self.logging_link_info(log_info)
                if "open_trades_sold_get_response" in resp.keys():
                    if "trades" in resp["open_trades_sold_get_response"].keys():
                        all_order = all_order + resp["open_trades_sold_get_response"]["trades"]["trade"]
                    req.page_no += 1
                    has_next = resp["open_trades_sold_get_response"]["has_next"]
            invoke_result_data.data = all_order
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            invoke_result_data.data = []
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_refund_order_list(self, buyer_nick, access_token,app_key, app_secret, start_modified="", end_modified="",page_size=50,is_log=False):
        """
        :description: 获取淘宝退款订单
        :param buyer_nick：用户昵称
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param start_modified：开始时间
        :param end_modified：结束时间
        :param page_size：页大小
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        all_order = []
        has_next = True
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.RefundsReceiveGetRequest()
            req.fields = "refund_id,tid,oid,title,total_fee,status,created,refund_fee,modified,num"
            # refund_id：退款单号, tid：淘宝交易单号, oid：子订单号, title：商品名称 , total_fee：订单总价, status：退款状态,
            # created：退款申请时间, refund_fee：退款金额, modified：更新时间, num: 购买数量
            req.type = "fixed"
            req.buyer_nick = buyer_nick
            req.page_size = page_size
            req.page_no = 1
            req.use_has_next = "true"

            if start_modified == "":
                start_timestamp = TimeHelper.get_now_timestamp() - 90 * 24 * 60 * 60
                start_modified = TimeHelper.timestamp_to_format_time(start_timestamp)
            req.start_modified = start_modified
            if end_modified != "":
                req.end_modified = end_modified
            while has_next:
                resp = req.getResponse(access_token)
                if is_log:
                    log_info = str(resp) + "【access_token】：" + access_token + "【获取退单订单】"
                    if self.context:
                        self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
                if "refunds_receive_get_response" in resp.keys():
                    if "refunds" in resp["refunds_receive_get_response"].keys():
                        all_order = all_order + resp["refunds_receive_get_response"]["refunds"]["refund"]
                    req.page_no += 1
                    has_next = resp["refunds_receive_get_response"]["has_next"]
            invoke_result_data.data = all_order
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            invoke_result_data.data = []
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def online_app(self, app_id, template_id, template_version, app_version, access_token,app_key, app_secret, is_log=False):
        """
        :description: app上线
        :param app_id：app_id
        :param template_id：模板id
        :param template_version：模板版本
        :param app_version：app版本
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.MiniappTemplateOnlineappRequest()

            req.clients = "taobao,tmall"
            req.app_id = app_id
            req.template_id = template_id
            req.template_version = template_version
            req.app_version = app_version
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【app上线】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_shop(self, access_token,app_key,app_secret,is_log=False):
        """
        :description: 获取店铺信息
        :param access_token：access_token
        :param is_log：是否记录返回信息
        :param app_key：app_key
        :param app_secret：app_secret
        :return: InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.ShopSellerGetRequest()
            req.fields = "sid,title,pic_path"
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【获取店铺信息】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_user_seller(self, access_token,app_key, app_secret,is_log=False):
        """
        :description: 获取关注店铺用户信息
        :param access_token：access_token
        :param app_key：app_key
        :param app_secret：app_secret
        :param is_log：是否记录返回信息
        :return: InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.UserSellerGetRequest()
            req.fields = "user_id,nick,sex"
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【获取关注店铺用户信息】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_dead_date(self, user_nick, access_token, app_key, app_secret, is_log=False):
        """
        :description: 获取订购过期时间
        :param user_nick：用户昵称
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            vas_subscribe_get_response = self.get_vas_subscribe(user_nick, access_token, app_key, app_secret, is_log)
            if not vas_subscribe_get_response:
                invoke_result_data.data = "expire"
                return invoke_result_data
            if "article_user_subscribe" not in vas_subscribe_get_response["article_user_subscribes"].keys():
                invoke_result_data.data = "expire"
                return invoke_result_data
            invoke_result_data.data = vas_subscribe_get_response["article_user_subscribes"]["article_user_subscribe"][0]["deadline"]
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_goods_list_by_goodsids(self, num_iids, access_token,app_key, app_secret, field="num_iid,title,nick,pic_url,price,input_str,property_alias,sku,props_name,outer_id,prop_img",is_log=False):
        """
        :description: 获取在售商品列表(num_iids上限20个，超过淘宝会报错)
        :param num_iids：商品id列表
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param field：返回字段
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        num_iid_list = num_iids.split(',')
        page_size = 20
        page_count = int(len(num_iid_list) / page_size) if len(num_iid_list) % page_size == 0 else int(len(num_iid_list) / page_size) + 1
        goods_list = []
        for i in range(0, page_count):
            cur_num_iids = ",".join(num_iid_list[i * page_size:page_size * (i + 1)])
            try:
                top.setDefaultAppInfo(app_key, app_secret)
                req = top.api.ItemsSellerListGetRequest()
                req.fields = field
                req.num_iids = cur_num_iids
                resp = req.getResponse(access_token)
                if is_log:
                    log_info = str(resp) + "【access_token】：" + access_token + "【获取在售商品列表by_goodsids】"
                    if self.context:
                        self.context.logging_link_info(log_info)
                    elif self.logging_link_info:
                        self.logging_link_info(log_info)

                if "items_seller_list_get_response" in resp.keys():
                    if "items" in resp["items_seller_list_get_response"].keys():
                        if "item" in resp["items_seller_list_get_response"]["items"].keys():
                            goods_list.extend(resp["items_seller_list_get_response"]["items"]["item"])
            except Exception as ex:
                if self.context:
                    self.context.logging_link_error(traceback.format_exc())
                elif self.logging_link_error:
                    self.logging_link_error(traceback.format_exc())
                invoke_result_data.success = False
                if "submsg" in str(ex):
                    content_list = str(ex).split()
                    for content in content_list:
                        if "submsg=该子帐号无此操作权限" in content:
                            invoke_result_data.error_code = "no_power"
                            invoke_result_data.error_message = content[len("submsg="):]
                            return invoke_result_data
                        if "submsg=num_iid有误，必须大于0" in content:
                            invoke_result_data.error_code = "param_error"
                            invoke_result_data.error_message = content[len("submsg="):]
                            return invoke_result_data
                        if "submsg=" in content:
                            invoke_result_data.error_code = "error"
                            invoke_result_data.error_message = content[len("submsg="):]
                            return invoke_result_data
                return invoke_result_data
        invoke_result_data.data = {"items_seller_list_get_response": {"items": {"item": goods_list}}}
        return invoke_result_data

    def get_goods_list(self, page_index, page_size, goods_name, order_tag, order_by, access_token,app_key, app_secret, field="num_iid,title,nick,price,input_str,property_alias,sku,props_name,pic_url", is_log=False):
        """
        :description: 获取在售商品列表（获取当前会话用户出售中的商品列表）
        :param page_index：页索引
        :param page_size：页大小
        :param goods_name：商品名称
        :param order_tag：order_tag
        :param order_by：排序类型
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param field:查询字段
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()

        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.ItemsOnsaleGetRequest()
            req.fields = field
            req.page_no = page_index + 1
            req.page_size = page_size
            if goods_name != "":
                req.q = goods_name
            if order_tag !="" and order_by !="":
                req.order_by = order_tag + ":" + order_by
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【获取在售商品列表】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if resp:
                resp["pageSize"] = page_size
                resp["pageIndex"] = page_index
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_goods_info(self, num_iid, access_token,app_key, app_secret, field="num_iid,title,nick,pic_url,price,item_img.url,outer_id,sku,approve_status,prop_img", is_log=False):
        """
        :description: 获取单个商品详细信息
        :param num_iid：num_iid
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param field：查询字段
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.ItemSellerGetRequest()

            req.fields = field
            req.num_iid = num_iid
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【获取单个商品详细信息】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_goods_inventory_list(self, page_index, page_size, goods_name, order_tag, order_by, access_token,app_key, app_secret, field="num_iid,title,nick,price,input_str,property_alias,sku,props_name,pic_url", is_log=False):
        """
        :description: 获取仓库商品列表（获取当前用户作为卖家的仓库中的商品列表）
        :param page_index：页索引
        :param page_size：页大小
        :param goods_name：商品名称
        :param order_tag：order_tag
        :param order_by：排序类型
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param field：查询字段
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.ItemsInventoryGetRequest()

            req.fields = field
            req.page_no = page_index
            req.page_size = page_size
            if goods_name != "":
                req.q = goods_name
            req.order_by = order_tag + ":" + order_by

            resp = req.getResponse(access_token)
            if resp:
                resp["pageSize"] = page_size
                resp["pageIndex"] = page_index
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token+ "【获取仓库商品列表】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def miniapp_distribution_items_bind(self, goods_ids, url, status, access_token,app_key, app_secret, is_log=False):
        """
        :description: 小程序投放-商品绑定/解绑（提供给使用了投放插件的服务商，可以调用该API实现帮助商家更新已创建的投放单中的绑定商品信息。）
        :param goods_ids：商品id列表逗号，分隔
        :param url：投放的商家应用完整链接
        :param status：true表示新增绑定，false表示解绑
        :param access_token:access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.MiniappDistributionItemsBindRequest()

            req.target_entity_list = goods_ids
            req.url = url
            req.add_bind = status
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【小程序投放商品】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def alibaba_benefit_query(self, right_ename,access_token,app_key, app_secret, is_log=False):
        """
        :description: 查询优惠券详情信息
        :param right_ename:奖池ID
        :param access_token:access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return: InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.AlibabaBenefitQueryRequest()
            req.ename = right_ename
            req.app_name = "promotioncenter-" + config.get_value("server_template_id")
            req.award_type = "1"
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【查询优惠券详情信息】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def alibaba_benefit_send(self, right_ename, open_id, access_token,app_key, app_secret, is_log=False):
        """
        :description: 发放优惠劵
        :param right_ename:奖池ID
        :param open_id:open_id
        :param access_token:access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return: InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.AlibabaBenefitSendRequest()
            req.right_ename = right_ename
            req.receiver_id = open_id
            req.user_type = "taobao"
            req.unique_id = str(open_id) + str(right_ename) + str(TimeHelper.get_now_timestamp())
            req.app_name = "promotioncenter-" + config.get_value("server_template_id")
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【发放优惠劵】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_member_info(self, mix_nick, nick, access_token, app_key, app_secret, is_log=False):
        """
        :description: 获取淘宝会员信息
        :param mix_nick:mix_nick
        :param nick:nick
        :param access_token:access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return:InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.CrmMemberIdentityGetRequest()
            if mix_nick:
                req.mix_nick = mix_nick
            if nick:
                req.nick = nick
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【获取淘宝会员信息】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def check_is_member(self, mix_nick, nick, access_token, app_key, app_secret, is_log=False):
        """
        :description: 实时查询当前是否店铺会员
        :param mix_nick:mix_nick
        :param nick:nick
        :param access_token:access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return:True是会员 False不是会员
        :last_editors: HuangJianYi
        """
        is_member = False
        invoke_result_data = self.get_member_info(mix_nick, nick, access_token, app_key, app_secret, is_log)
        if invoke_result_data.success == False:
            return is_member
        resp = invoke_result_data.data
        if "crm_member_identity_get_response" in resp.keys():
            if "result" in resp["crm_member_identity_get_response"].keys():
                if "member_info" in resp["crm_member_identity_get_response"]["result"].keys():
                    is_member = True
        return is_member

    def get_join_member_url(self, access_token,app_key, app_secret,is_log=False):
        """
        :description: 获取加入会员地址
        :param access_token:access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return:InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.CrmMemberJoinurlGetRequest()
            req.callback_url = ""
            req.extra_info = "{\"source\":\"isvapp\",\"activityId\":\"\",\"entrance\":\"hudong\"}"
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【获取加入会员地址】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if "crm_member_joinurl_get_response" in resp.keys():
                if "result" in resp["crm_member_joinurl_get_response"].keys():
                    if "result" in resp["crm_member_joinurl_get_response"]["result"].keys():
                        invoke_result_data.data = resp["crm_member_joinurl_get_response"]["result"]["result"]
                        if invoke_result_data.data and "https:" not in invoke_result_data.data and "http:" not in invoke_result_data.data:
                            invoke_result_data.data = "https:" + invoke_result_data.data
                        return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def open_trade_special_items_query(self, app_id, access_token,app_key, app_secret,is_log=False):
        """
        :description: 专属下单查询
        :param app_id：app_id
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        resp = {}
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.OpentradeSpecialItemsQueryRequest()
            req.miniapp_id = app_id
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【专属下单查询】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            invoke_result_data.data = resp
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def open_trade_special_userk_mark(self, goods_id, open_id, access_token,app_key, app_secret,is_log=False):
        """
        :description: 专属下单可购买用户标记
        :param goods_id：商品id
        :param open_id：open_id
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return 
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.OpentradeSpecialUsersMarkRequest()
            req.hit = "true"
            req.open_user_ids = str(open_id)
            req.item_id = int(goods_id)
            req.sku_id = 0
            req.status = "MARK"
            req.limit_num = 1
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【专属下单可购买用户标记】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if resp and resp["opentrade_special_users_mark_response"]["result"] == 1:
                #  ------------ TopOpentradeSpecialUserMark: {'opentrade_special_users_mark_response': {'result': 1, 'request_id': 'rsk23xhlk310'}}
                invoke_result_data.data = True
            else:
                invoke_result_data.data = False
            return invoke_result_data

        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def open_trade_special_items_bind(self, app_id, goods_id, access_token,app_key, app_secret, is_log=False):
        """
        :description: 专属下单商品绑定
        :param app_id：app_id
        :param goods_id：goods_id
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return 
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.OpentradeSpecialItemsBindRequest()

            req.miniapp_id = app_id
            req.item_ids = str(goods_id)
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【专属下单商品绑定】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            # {'opentrade_special_items_bind_response': {'results': {'item_bind_result': [{'bind_ok': False, 'error_message': '商品已绑定到小程序:情之缘1993_好货跳一跳_[3000000029278805]', 'item_id': 632007280726}]}, 'request_id': 'zrq8mt8d8xdo'}}
            if resp["opentrade_special_items_bind_response"]["results"]["item_bind_result"][0]:
                if not resp["opentrade_special_items_bind_response"]["results"]["item_bind_result"][0]["bind_ok"]:
                    invoke_result_data.success = False
                    invoke_result_data.error_code = "error"
                    invoke_result_data.error_message = resp["opentrade_special_items_bind_response"]["results"]["item_bind_result"][0]["error_message"]
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def get_project_code(self, user_nick, access_token,app_key, app_secret,is_log=False):
        """
        :description: 获取项目编码
        :param user_nick：用户昵称
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return list
        :last_editors: HuangJianYi
        """
        try:
            vas_subscribe_get_response = self.get_vas_subscribe(user_nick, access_token, app_key, app_secret, is_log)
            if not vas_subscribe_get_response:
                return ""
            if "article_user_subscribe" not in vas_subscribe_get_response["article_user_subscribes"].keys():
                return ""
            return vas_subscribe_get_response["article_user_subscribes"]["article_user_subscribe"][0]["item_code"]
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            return ""

    def get_vas_subscribe(self, user_nick, access_token,app_key, app_secret,is_log=False):
        """
        :description:订购关系查询 用于ISV根据登录进来的淘宝会员名查询该为该会员开通哪些收费项目，ISV只能查询自己名下的应用及收费项目的订购情况
        :param user_nick：用户昵称
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return 订购关系
        :last_editors: HuangJianYi
        """
        try:
            redis_init = SevenHelper.redis_init()
            cache_key = f"get_vas_subscribe:{user_nick}"
            vas_subscribe_get_response = redis_init.get(cache_key)
            if vas_subscribe_get_response:
                return json.loads(vas_subscribe_get_response)
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.VasSubscribeGetRequest()
            req.article_code = config.get_value("article_code")
            req.nick = user_nick
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【订购关系查询】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            redis_init.set(cache_key, json.dumps(resp["vas_subscribe_get_response"]),5)
            return resp["vas_subscribe_get_response"]
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            return None

    def get_short_url(self, url, access_token, app_key, app_secret, is_log=False):
        """
        :description: 获取短链接
        :param url：链接地址
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return 短链接地址
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.MiniappShorturlCreateRequest()
            req.article_code = config.get_value("article_code")
            req.miniapp_url = url
            resp = req.getResponse(access_token)
            if is_log:
                log_info = str(resp) + "【access_token】：" + access_token + "【获取短链接】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if "miniapp_shorturl_create_response" not in  resp:
                invoke_result_data.success = False
                return invoke_result_data
            if "result" not in resp["miniapp_shorturl_create_response"]:
                invoke_result_data.success = False
                return invoke_result_data
            if "model" not in resp["miniapp_shorturl_create_response"]["result"]:
                invoke_result_data.success = False
                return invoke_result_data
            if "short_url" not in resp["miniapp_shorturl_create_response"]["result"]["model"]:
                invoke_result_data.success = False
                return invoke_result_data
            invoke_result_data.data = resp["miniapp_shorturl_create_response"]["result"]["model"]["short_url"]
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            return invoke_result_data

    def get_crm_point_available(self, user_nick, access_token, app_key, app_secret, is_log=False):
        """
        :description: 获取店铺会员积分
        :param user_nick：用户昵称
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param is_log：是否记录返回信息
        :return 返回店铺会员积分
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.CrmPointAvailableGetRequest()
            req.buyer_nick = user_nick
            resp = req.getResponse(access_token)
            if is_log:
                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + str(resp) +  "【access_token】：" + access_token + "【获取店铺会员积分】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if "crm_point_available_get_response" not in  resp:
                invoke_result_data.success = False
                return invoke_result_data
            if "result" not in resp["crm_point_available_get_response"]:
                invoke_result_data.success = False
                return invoke_result_data
            invoke_result_data.data = resp["crm_point_available_get_response"]["result"]
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data

    def change_crm_point(self, open_id, change_type, opt_type, quantity, access_token, app_key, app_secret, activity_id=0, activity_name="", is_log=False):
        """
        :description: 操作店铺会员积分
        :param open_id：买家open_id
        :param change_type：变更类型：0交易，1：互动活动，2：权益兑换，3：手工调整
        :param opt_type：操作类型，0：增加，1：扣减
        :param quantity：积分数量
        :param access_token：access_token
        :param app_key:app_key
        :param app_secret:app_secret
        :param activity_id：活动Id
        :param activity_name：活动名称
        :param is_log：是否记录返回信息
        :return 返回操作结果
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            top.setDefaultAppInfo(app_key, app_secret)
            req = top.api.CrmPointChangeRequest()
            if activity_id > 0:
                req.activity_id = activity_id
            if activity_name:
                req.activity_name = activity_name
            req.change_type = change_type
            req.opt_type = opt_type
            req.quantity = quantity
            req.open_id = open_id
            resp = req.getResponse(access_token)
            if is_log:
                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + str(resp) + "【access_token】：" + access_token + "【操作店铺会员积分】"
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if "crm_point_change_response" not in resp:
                invoke_result_data.success = False
                return invoke_result_data
            if "result" not in resp["crm_point_change_response"]:
                invoke_result_data.success = False
                return invoke_result_data
            invoke_result_data.data = resp["crm_point_change_response"]["result"]
            return invoke_result_data
        except Exception as ex:
            if self.context:
                self.context.logging_link_error(traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error(traceback.format_exc())
            invoke_result_data.success = False
            if "submsg" in str(ex):
                content_list = str(ex).split()
                for content in content_list:
                    if "submsg=该子帐号无此操作权限" in content:
                        invoke_result_data.error_code = "no_power"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
                    if "submsg=" in content:
                        invoke_result_data.error_code = "error"
                        invoke_result_data.error_message = content[len("submsg="):]
                        return invoke_result_data
            return invoke_result_data


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-11-26 10:22:44
@LastEditTime: 2022-02-25 14:14:48
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.models.seven_model import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.models.seven_model import PageInfo
from seven_cloudapp_frame.models.db_models.cms.cms_info_model import *

class CmsBaseModel():
    """
    :description: 位置信息（资讯）相关业务模型 用于后台或者中台案例和教程等配置信息
    """
    def __init__(self,context=None,logging_error=None,logging_info=None):
        self.context = context
        self.logging_link_error = logging_error
        self.logging_link_info = logging_info

    def _delete_cms_info_dependency_key(self, place_id, delay_delete_time=0.1):
        """
        :description: 删除位置信息依赖建
        :param place_id: 位置标识
        :param act_id: 活动标识
        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
        :return: 
        :last_editors: HuangJianYi
        """
        if delay_delete_time > 0:
            time.sleep(delay_delete_time)
        count = 0
        while count <= 2:
            count += 1
            try:
                redis_init = SevenHelper.redis_init()
                if place_id:
                    redis_init.delete(f"data_cache:dependency_cms_info_list:placeid_{place_id}")
                break
            except:
                pass

    def save_cms_info(self, place_id, cms_id, app_id, act_id, info_title, simple_title, simple_title_url, info_type, info_summary, info_tag, info_mark, target_url, min_pic, mid_pic, max_pic, info_data, pic_collect_json, sort_index, is_release, i1, i2, i3, i4, s1, s2, s3, s4):
        """
        :description: 保存位置信息
        :param place_id：位置标识
        :param cms_id：信息标识
        :param app_id：应用标识
        :param act_id：活动标识
        :param info_title：信息标题
        :param simple_title：信息短标题
        :param simple_title_url：短标题链接
        :param info_type：短标题链接
        :param info_summary：短标题链接
        :param info_tag：信息标签[文章内容特性][砍人事件]
        :param info_mark：信息标记[首发,推荐,独家，热门]
        :param target_url：跳转地址
        :param min_pic：信息小图
        :param mid_pic：信息中图
        :param max_pic：信息大图
        :param info_data：信息内容
        :param pic_collect_json：图集json
        :param sort_index：排序
        :param is_release：是否发布（1是0否）
        :param i1：i1
        :param i2：i2
        :param i3：i3
        :param i4：i4
        :param s1：s1
        :param s2：s2
        :param s3：s3
        :param s4：s4
        :return
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        if not place_id or not info_title:
            invoke_result_data.success = False
            invoke_result_data.error_code = "param_error"
            invoke_result_data.error_message = "参数不能为空或等于0"
            return invoke_result_data

        cms_info = None
        is_add = False
        cms_info_model = CmsInfoModel(context=self.context)
        if cms_id > 0:
            cms_info = cms_info_model.get_entity_by_id(cms_id)
            if not cms_info or (app_id and cms_info.app_id != app_id):
                invoke_result_data.success = False
                invoke_result_data.error_code = "error"
                invoke_result_data.error_message = "信息不存在"
                return invoke_result_data
            old_cms_info = deepcopy(cms_info)
        if not cms_info:
            is_add = True
            cms_info = CmsInfo()
        cms_info.place_id = place_id
        cms_info.app_id = app_id
        cms_info.act_id = act_id
        cms_info.info_title = info_title
        cms_info.simple_title = simple_title
        cms_info.simple_title_url = simple_title_url
        cms_info.info_type = info_type
        cms_info.info_summary = info_summary
        cms_info.info_tag = info_tag
        cms_info.info_mark = info_mark
        cms_info.target_url = target_url
        cms_info.min_pic = min_pic
        cms_info.mid_pic = mid_pic
        cms_info.max_pic = max_pic
        cms_info.info_data = info_data
        cms_info.pic_collect_json = pic_collect_json if pic_collect_json else []
        cms_info.sort_index = sort_index
        cms_info.i1 = i1
        cms_info.i2 = i2
        cms_info.i3 = i3
        cms_info.i4 = i4
        cms_info.s1 = s1
        cms_info.s2 = s2
        cms_info.s3 = s3
        cms_info.s4 = s4
        cms_info.modify_date = SevenHelper.get_now_datetime()
        cms_info.is_release = is_release
        if is_release == 1:
            cms_info.release_date = cms_info.modify_date
        if is_add:
            cms_info.create_date = cms_info.modify_date
            cms_info.id = cms_info_model.add_entity(cms_info)
        else:
            cms_info_model.update_entity(cms_info,exclude_field_list="place_id,app_id,act_id,create_date")
        result = {}
        result["is_add"] = is_add
        result["new"] = cms_info
        result["old"] = old_cms_info
        invoke_result_data.data = result
        self._delete_cms_info_dependency_key(place_id)
        return invoke_result_data

    def get_cms_info_list(self, place_id, page_size, page_index, order_by="id desc",field="*", app_id="", act_id=0, is_cache=True):
        """
        :description: 位置信息列表
        :param place_id：位置标识
        :param page_size：页大小
        :param page_index：页索引
        :param order_by：排序
        :param field：查询字段
        :param app_id：应用标识
        :param act_id：活动标识
        :param is_cache：是否缓存
        :return:
        :last_editors: HuangJianYi
        """
        page_info = PageInfo(page_index, page_size, 0, [])
        if not place_id:
            return page_info
        condition = "place_id=%s and is_release=1"
        params = [place_id]
        if act_id:
            condition+=" and act_id=%s"
            params.append(act_id)
        if app_id:
            condition+=" and app_id=%s"
            params.append(app_id)
        cms_info_model = CmsInfoModel(context=self.context)
        if is_cache == True:
            page_list, total = cms_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=f"cms_info_list:placeid_{place_id}",cache_expire=600)
        else:
            page_list, total = cms_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
        page_info = PageInfo(page_index, page_size, total, page_list)
        return page_info



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-28 09:54:51
@LastEditTime: 2022-02-25 14:10:00
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.models.seven_model import *

from seven_cloudapp_frame.models.db_models.base.base_info_model import *
from seven_cloudapp_frame.models.db_models.act.act_type_model import *
from seven_cloudapp_frame.models.db_models.app.app_info_model import *
from seven_cloudapp_frame.models.db_models.act.act_info_model import *
from seven_cloudapp_frame.models.db_models.act.act_prize_model import *


class ActBaseModel():
    """
    :description: 活动信息业务模型
    """
    def __init__(self,context=None,logging_error=None,logging_info=None):
        self.context = context
        self.logging_link_error = logging_error
        self.logging_link_info = logging_info

    def _delete_act_info_dependency_key(self,app_id,act_id,delay_delete_time=0.1):
        """
        :description: 删除活动信息依赖建
        :param app_id: 应用标识
        :param act_id: 活动标识
        :param delay_delete_time: 延迟删除时间，传0则不进行延迟
        :return: 
        :last_editors: HuangJianYi
        """
        if delay_delete_time > 0:
            time.sleep(delay_delete_time)
        count = 0
        while count <= 2:
            count += 1
            try:
                redis_init = SevenHelper.redis_init()
                if act_id:
                    redis_init.delete(f"data_cache:dependency_act_info:actid_{act_id}")
                if app_id:
                    redis_init.delete(f"data_cache:dependency_act_info_list:appid_{app_id}")
                break
            except:
                pass

    def get_act_info_dict(self,act_id,is_cache=True,is_filter=True):
        """
        :description: 获取活动信息
        :param act_id: 活动标识
        :param is_cache: 是否缓存
        :param is_filter: 是否过滤未发布或删除的数据
        :return: 返回活动信息
        :last_editors: HuangJianYi
        """
        act_info_model = ActInfoModel(context=self.context)
        if is_cache:
            dependency_key = f"act_info:actid_{act_id}"
            act_info_dict = act_info_model.get_cache_dict_by_id(act_id,dependency_key=dependency_key)
        else:
            act_info_dict = act_info_model.get_dict_by_id(act_id)
        if is_filter == True:
            if not act_info_dict or act_info_dict["is_release"] == 0 or act_info_dict["is_del"] == 1:
                return None
        return act_info_dict

    def get_act_info_list(self,app_id,act_name,is_del,page_size,page_index,is_cache=True):
        """
        :description: 获取活动信息列表
        :param app_id: 应用标识
        :param act_name: 活动名称
        :param is_del: 是否回收站1是0否
        :param page_size: 条数
        :param page_index: 页数
        :param is_cache: 是否缓存
        :return: 
        :last_editors: HuangJianYi
        """
        order_by = "id asc"
        condition = "app_id=%s"
        params = [app_id]
        if is_del !=-1:
            condition += " and is_del=%s"
            params.append(is_del)
        if act_name:
            condition += " and act_name=%s"
            params.append(act_name)
        if is_cache:
            page_list, total = ActInfoModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params,dependency_key=f"act_info_list:appid_{app_id}")
        else:
            page_list, total = ActInfoModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params)
        for page in page_list:
            page["share_desc_json"] = SevenHelper.json_loads(page["share_desc_json"]) if page["share_desc_json"] else {}
            page["rule_desc_json"] = SevenHelper.json_loads(page["rule_desc_json"]) if page["rule_desc_json"] else []
            page["finish_menu_config_json"] = SevenHelper.json_loads(page["finish_menu_config_json"]) if page["finish_menu_config_json"] else []
            page["finish_status"] = page["is_finish"]
        return page_list, total

    def add_act_info(self,app_id,act_name,act_type,theme_id,share_desc_json,rule_desc_json,close_word="抱歉，程序维护中"):
        """
        :description: 添加活动信息
        :param app_id: 应用标识
        :param act_name: 活动名称
        :param act_type: 活动类型
        :param theme_id: 主题标识
        :param share_desc_json: 分享配置
        :param rule_desc_json: 规则配置
        :param close_word: 关闭文案
        :return: 
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        if not app_id:
            invoke_result_data.success = False
            invoke_result_data.error_code = "param_error"
            invoke_result_data.error_message = "参数不能为空或等于0"
            return invoke_result_data
        if not act_name:
            base_info_model = BaseInfoModel(context=self.context)
            base_info_dict = base_info_model.get_cache_dict()
            if not base_info_dict:
                invoke_result_data.success = False
                invoke_result_data.error_code = "error"
                invoke_result_data.error_message = "基础信息不存在"
                return invoke_result_data
        act_type_model = ActTypeModel(context=self.context)
        act_type_info = act_type_model.get_entity("id=%s", params=act_type)
        if not act_type_info:
            invoke_result_data.success = False
            invoke_result_data.error_code = "error"
            invoke_result_data.error_message = "活动类型信息不存在"
            return invoke_result_data

        now_datetime = SevenHelper.get_now_datetime()
        act_info_model = ActInfoModel(context=self.context)
        act_count = act_info_model.get_total("app_id=%s", params=[app_id])

        act_info = ActInfo()
        act_info.app_id = app_id
        act_info.act_name = base_info_dict["product_name"] + "_" + str(act_count + 1) if not act_name else act_name
        act_info.act_type = act_type
        act_info.theme_id = theme_id
        act_info.close_word = close_word
        act_info.share_desc_json = share_desc_json if share_desc_json else {}
        act_info.rule_desc_json = rule_desc_json if rule_desc_json else []
        act_info.start_date = now_datetime
        act_info.end_date = "2900-01-01 00:00:00"
        act_info.task_asset_type_json = act_type_info.task_asset_type_json
        act_info.is_release = 1
        act_info.release_date = now_datetime
        act_info.create_date = now_datetime
        act_info.modify_date = now_datetime
        act_info.id = act_info_model.add_entity(act_info)
        invoke_result_data.data = act_info
        self._delete_act_info_dependency_key(app_id,act_info.id)
        return invoke_result_data

    def update_act_info(self,app_id,act_id,act_name,theme_id,is_share,share_desc_json,is_rule,rule_desc_json,is_release,start_date,end_date,is_black,refund_count,join_ways,is_fictitious,close_word="抱歉，程序维护中",store_url=None,i1=-1,i2=-1,i3=-1,i4=-1,i5=-1,s1=None,s2=None,s3=None,s4=None,s5=None,d1=None,d2=None,is_visit_store=-1):
        """
        :description: 修改活动信息
        :param app_id: 应用标识
        :param act_id：活动标识
        :param act_name：活动名称
        :param is_release：是否发布
        :param theme_id: 主题标识
        :param is_share: 是否开启分享
        :param share_desc_json: 分享配置
        :param is_rule: 是否开启规则
        :param rule_desc_json: 规则配置
        :param start_date: 开始时间
        :param end_date: 结束时间
        :param close_word: 关闭文案
        :param is_black：是否开启退款惩罚
        :param refund_count：退款成功次数
        :param join_ways: 活动参与条件（0所有1关注店铺2加入会员3指定用户）
        :param is_fictitious: 是否开启虚拟中奖（1是0否）
        :param i1: i1
        :param i2: i2
        :param i3: i3
        :param i4: i4
        :param i5: i5
        :param s1: s1
        :param s2: s2
        :param s3: s3
        :param s4: s4
        :param s5: s5
        :param d1: d1
        :param d2: d2
        :param is_visit_store: 是否开启访问店铺
        :return: 
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        act_info_model = ActInfoModel(context=self.context)
        act_info = act_info_model.get_entity_by_id(act_id)
        if not act_info or act_info.app_id != app_id:
            invoke_result_data.success = False
            invoke_result_data.error_code = "no_act"
            invoke_result_data.error_message = "活动信息不存在"
            return invoke_result_data
        old_act_info = deepcopy(act_info)
        now_datetime = SevenHelper.get_now_datetime()
        if act_name !=None:
            act_info.act_name = act_name
        if is_release !=-1:
            act_info.is_release = is_release
        if theme_id !=-1:
            act_info.theme_id = theme_id
        if is_share !=-1:
            act_info.is_share = is_share
        if share_desc_json !=None:
            act_info.share_desc_json = share_desc_json
        if is_rule !=-1:
            act_info.is_rule = is_rule
        if rule_desc_json !=None:
            act_info.rule_desc_json = rule_desc_json
        if is_release !=-1:
            act_info.is_release = is_release
            act_info.release_date = now_datetime
        if start_date !=None:
            act_info.start_date = start_date
        if end_date !=None:
            act_info.end_date = end_date
        if is_black !=-1:
            act_info.is_black = is_black
        if refund_count !=-1:
            act_info.refund_count = refund_count
        if join_ways !=-1:
            act_info.join_ways = join_ways
        if is_fictitious !=-1:
            act_info.is_fictitious = is_fictitious
        if close_word !=None:
            act_info.close_word = close_word
        if is_visit_store !=-1:
            act_info.is_visit_store = is_visit_store
        if store_url !=None:
            act_info.store_url = store_url
        if i1 !=-1:
            act_info.i1 = i1
        if i2 !=-1:
            act_info.i2 = i2
        if i3 !=-1:
            act_info.i3 = i3
        if i4 !=-1:
            act_info.i4 = i4
        if i5 !=-1:
            act_info.i5 = i5
        if s1 !=None:
            act_info.s1 = s1
        if s2 !=None:
            act_info.s2 = s2
        if s3 !=None:
            act_info.s3 = s3
        if s4 !=None:
            act_info.s4 = s4
        if s5 !=None:
            act_info.s5 = s5
        if d1 !=None:
            act_info.d1 = d1
        if d2 !=None:
            act_info.d2 = d2
        act_info.modify_date = now_datetime
        act_info_model.update_entity(act_info,exclude_field_list="finish_menu_config_json,is_finish,task_asset_type_json,is_launch")
        result = {}
        result["old"] = old_act_info
        result["new"] = act_info
        invoke_result_data.data = result
        self._delete_act_info_dependency_key(app_id,act_info.id)
        return invoke_result_data

    def update_act_info_status(self,app_id,act_id,is_del):
        """
        :description: 删除或者还原活动
        :param app_id：应用标识
        :param act_id：活动标识
        :param is_del：0-还原，1-删除
        :return: 
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        act_info_model = ActInfoModel(context=self.context)
        act_info_dict = act_info_model.get_dict_by_id(act_id)
        if not act_info_dict or act_info_dict["app_id"]!=app_id:
            invoke_result_data.success = False
            invoke_result_data.error_code = "no_act"
            invoke_result_data.error_message = "活动信息不存在"
            return invoke_result_data
        is_release = 0 if is_del == 1 else 1
        modify_date = SevenHelper.get_now_datetime()
        invoke_result_data.success = act_info_model.update_table("is_del=%s,is_release=%s,release_date=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, act_id])
        self._delete_act_info_dependency_key(app_id,act_id)
        return invoke_result_data

    def release_act_info(self,app_id,act_id,is_release):
        """
        :description: ip上下架
        :param app_id：应用标识
        :param act_id：活动标识
        :param is_release: 是否发布 1-是 0-否
        :return: 
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        act_info_model = ActInfoModel(context=self.context)
        act_info_dict = act_info_model.get_dict_by_id(act_id)
        if not act_info_dict or act_info_dict["app_id"]!=app_id:
            invoke_result_data.success = False
            invoke_result_data.error_code = "no_act"
            invoke_result_data.error_message = "活动信息不存在"
            return invoke_result_data
        invoke_result_data.success = act_info_model.update_table("release_date=%s,is_release=%s", "id=%s", [SevenHelper.get_now_datetime(), is_release, act_id])
        self._delete_act_info_dependency_key(app_id,act_id)
        return invoke_result_data

    def next_progress(self,app_id,act_id,finish_key):
        """
        :description: 下一步配置
        :param app_id：应用标识
        :param finish_key：完成key，由前端控制是否完成配置，完成时需传参数值finish_config 代表最后一步
        :return: 
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        base_info_model = BaseInfoModel(context=self.context)
        base_info = base_info_model.get_entity()
        if not base_info:
            invoke_result_data.success = False
            invoke_result_data.error_code = "error"
            invoke_result_data.error_message = "基础信息不存在"
            return invoke_result_data
        act_info_model = ActInfoModel(context=self.context)
        act_info = act_info_model.get_dict_by_id(act_id)
        if not act_info:
            invoke_result_data.success = False
            invoke_result_data.error_code = "no_act"
            invoke_result_data.error_message = "活动信息不存在"
            return invoke_result_data
        menu_config_json = SevenHelper.json_loads(base_info.menu_config_json)
        menu = [menu for menu in menu_config_json if menu["key"] == finish_key]
        if len(menu) == 0:
            invoke_result_data.success = False
            invoke_result_data.error_code = "error"
            invoke_result_data.error_message = "对不起，无此菜单"
            return invoke_result_data
        if act_info["finish_menu_config_json"] != "" and finish_key in act_info["finish_menu_config_json"]:
            return invoke_result_data
        if act_info["finish_menu_config_json"] == "":
            act_info["finish_menu_config_json"] = "[]"
        finish_menu_config_json = SevenHelper.json_loads(act_info["finish_menu_config_json"])
        finish_menu_config_json.append(finish_key)

        result_finish_menu_config_json = []
        for item in finish_menu_config_json:
            is_exist = [item2 for item2 in menu_config_json if item2["key"] == item]
            if len(is_exist) > 0:
                result_finish_menu_config_json.append(item)
        is_finish = 0
        if finish_key == "finish_config" and act_info["is_finish"] == 0:
            is_finish = 1
        result_finish_menu_config_json = SevenHelper.json_dumps(result_finish_menu_config_json)
        act_info_model.update_table("finish_menu_config_json=%s,is_finish=%s", "id=%s", [result_finish_menu_config_json, is_finish, act_id])
        app_id = self.get_app_id()
        if is_finish == 1 and app_id:
            app_info_model = AppInfoModel(context=self.context)
            app_info_model.update_table("is_setting=1", "app_id=%s", [app_id])
        return invoke_result_data
